(v1.2.1)=
### 1.2.1 {small}`2018-06-08`

#### Plotting of {ref}`pl-generic` marker genes and quality control.

- {func}`~scanpy.pl.highest_expr_genes` for quality control; plot genes with highest mean fraction of cells, similar to `plotQC` of *Scater* {cite:p}`McCarthy2017` {pr}`169` {smaller}`F Ramirez`
